@@ -53,7 +53,7 @@
 
 #include "qtwebenginewidgetsglobal.h"
 
-#include "qwebenginedownloaditem_p.h"
+#include "qwebenginedownloaditem.h"
 #include "qwebengineprofile_p.h"
 #include <QString>
 
@@ -70,6 +70,7 @@ public:
 
     bool downloadFinished;
     quint32 downloadId;
+    qint64 startTime;
     QWebEngineDownloadItem::DownloadState downloadState;
     QWebEngineDownloadItem::SavePageFormat savePageFormat;
     QWebEngineDownloadItem::DownloadType type;
@@ -78,12 +79,18 @@ public:
     const QUrl downloadUrl;
     QString mimeType;
     bool downloadPaused;
+    QString suggestedFileName;
+    QString downloadDirectory;
+    QString downloadFileName;
+    bool isCustomFileName;
 
     qint64 totalBytes;
     qint64 receivedBytes;
     QWebEnginePage *page;
 
     void update(const QtWebEngineCore::ProfileAdapterClient::DownloadItemInfo &info);
+
+    void setFinished();
 };
 
 QT_END_NAMESPACE
